<?php

return [
    'Names' => [
        'aa' => 'afar',
        'ab' => 'abkhasisk',
        'ace' => 'achinesisk',
        'ach' => 'acoli',
        'ada' => 'adangme',
        'ady' => 'adyghe',
        'ae' => 'avestan',
        'af' => 'afrikaans',
        'afh' => 'afrihili',
        'agq' => 'aghem',
        'ain' => 'ainu',
        'ak' => 'akan',
        'akk' => 'akkadisk',
        'ale' => 'aleutisk',
        'alt' => 'sydaltaisk',
        'am' => 'amharisk',
        'an' => 'aragonsk',
        'ang' => 'oldengelsk',
        'ann' => 'obolo',
        'anp' => 'angika',
        'ar' => 'arabisk',
        'arc' => 'aramæisk',
        'arn' => 'mapudungun',
        'arp' => 'arapaho',
        'ars' => 'Najd-arabisk',
        'arw' => 'arawak',
        'as' => 'assamesisk',
        'asa' => 'asu',
        'ast' => 'asturisk',
        'atj' => 'atikamekw',
        'av' => 'avarisk',
        'awa' => 'awadhi',
        'ay' => 'aymara',
        'az' => 'aserbajdsjansk',
        'ba' => 'bashkir',
        'bal' => 'baluchi',
        'ban' => 'balinesisk',
        'bas' => 'basaa',
        'bax' => 'bamun',
        'bbj' => 'ghomala',
        'be' => 'belarusisk',
        'bej' => 'beja',
        'bem' => 'bemba',
        'bez' => 'bena',
        'bfd' => 'bafut',
        'bg' => 'bulgarsk',
        'bgc' => 'harianvi',
        'bgn' => 'vestbaluchi',
        'bho' => 'bhojpuri',
        'bi' => 'bislama',
        'bik' => 'bikol',
        'bin' => 'bini',
        'bkm' => 'kom',
        'bla' => 'siksika',
        'blo' => 'anii',
        'bm' => 'bambara',
        'bn' => 'bengali',
        'bo' => 'tibetansk',
        'br' => 'bretonsk',
        'bra' => 'braj',
        'brx' => 'bodo',
        'bs' => 'bosnisk',
        'bss' => 'bakossi',
        'bua' => 'buriatisk',
        'bug' => 'buginesisk',
        'bum' => 'bulu',
        'byn' => 'blin',
        'byv' => 'medumba',
        'ca' => 'catalansk',
        'cad' => 'caddo',
        'car' => 'caribisk',
        'cay' => 'cayuga',
        'cch' => 'atsam',
        'ccp' => 'chakma',
        'ce' => 'tjetjensk',
        'ceb' => 'cebuano',
        'cgg' => 'chiga',
        'ch' => 'chamorro',
        'chb' => 'chibcha',
        'chg' => 'chagatai',
        'chk' => 'chuukese',
        'chm' => 'mari',
        'chn' => 'chinook',
        'cho' => 'choctaw',
        'chp' => 'chipewyan',
        'chr' => 'cherokee',
        'chy' => 'cheyenne',
        'ckb' => 'sorani',
        'clc' => 'chilcotin',
        'co' => 'korsikansk',
        'cop' => 'koptisk',
        'cr' => 'cree',
        'crg' => 'michif',
        'crh' => 'krimtatarisk',
        'crj' => 'sydøstcree',
        'crk' => 'plains cree',
        'crl' => 'nordøstcree',
        'crm' => 'Moose-cree',
        'crr' => 'carolina algonquisk',
        'crs' => 'seselwa (kreol-fransk)',
        'cs' => 'tjekkisk',
        'csb' => 'kasjubisk',
        'csw' => 'swampy cree',
        'cu' => 'kirkeslavisk',
        'cv' => 'tjuvasjisk',
        'cy' => 'walisisk',
        'da' => 'dansk',
        'dak' => 'dakota',
        'dar' => 'dargwa',
        'dav' => 'taita',
        'de' => 'tysk',
        'del' => 'delaware',
        'den' => 'athapaskisk',
        'dgr' => 'dogrib',
        'din' => 'dinka',
        'dje' => 'zarma',
        'doi' => 'dogri',
        'dsb' => 'nedersorbisk',
        'dua' => 'duala',
        'dum' => 'middelhollandsk',
        'dv' => 'divehi',
        'dyo' => 'jola-fonyi',
        'dyu' => 'dyula',
        'dz' => 'dzongkha',
        'dzg' => 'dazaga',
        'ebu' => 'kiembu',
        'ee' => 'ewe',
        'efi' => 'efik',
        'egy' => 'oldegyptisk',
        'eka' => 'ekajuk',
        'el' => 'græsk',
        'elx' => 'elamitisk',
        'en' => 'engelsk',
        'enm' => 'middelengelsk',
        'eo' => 'esperanto',
        'es' => 'spansk',
        'et' => 'estisk',
        'eu' => 'baskisk',
        'ewo' => 'ewondo',
        'fa' => 'persisk',
        'fan' => 'fang',
        'fat' => 'fanti',
        'ff' => 'fulah',
        'fi' => 'finsk',
        'fil' => 'filippinsk',
        'fj' => 'fijiansk',
        'fo' => 'færøsk',
        'fon' => 'fon',
        'fr' => 'fransk',
        'frc' => 'cajunfransk',
        'frm' => 'middelfransk',
        'fro' => 'oldfransk',
        'frr' => 'nordfrisisk',
        'frs' => 'østfrisisk',
        'fur' => 'friulisk',
        'fy' => 'vestfrisisk',
        'ga' => 'irsk',
        'gaa' => 'ga',
        'gag' => 'gagauzisk',
        'gan' => 'gan-kinesisk',
        'gay' => 'gayo',
        'gba' => 'gbaya',
        'gd' => 'skotsk gælisk',
        'gez' => 'geez',
        'gil' => 'gilbertesisk',
        'gl' => 'galicisk',
        'gmh' => 'middelhøjtysk',
        'gn' => 'guarani',
        'goh' => 'oldhøjtysk',
        'gon' => 'gondi',
        'gor' => 'gorontalo',
        'got' => 'gotisk',
        'grb' => 'grebo',
        'grc' => 'oldgræsk',
        'gsw' => 'schweizertysk',
        'gu' => 'gujarati',
        'guz' => 'gusii',
        'gv' => 'manx',
        'gwi' => 'gwichin',
        'ha' => 'hausa',
        'hai' => 'haida',
        'hak' => 'hakka-kinesisk',
        'haw' => 'hawaiiansk',
        'hax' => 'sydhaida',
        'he' => 'hebraisk',
        'hi' => 'hindi',
        'hil' => 'hiligaynon',
        'hit' => 'hittitisk',
        'hmn' => 'hmong',
        'ho' => 'hirimotu',
        'hr' => 'kroatisk',
        'hsb' => 'øvresorbisk',
        'hsn' => 'xiang-kinesisk',
        'ht' => 'haitisk',
        'hu' => 'ungarsk',
        'hup' => 'hupa',
        'hur' => 'halkomelem',
        'hy' => 'armensk',
        'hz' => 'herero',
        'ia' => 'interlingua',
        'iba' => 'iban',
        'ibb' => 'ibibio',
        'id' => 'indonesisk',
        'ie' => 'interlingue',
        'ig' => 'igbo',
        'ii' => 'sichuan yi',
        'ik' => 'inupiaq',
        'ikt' => 'vestcanadisk inuktitut',
        'ilo' => 'iloko',
        'inh' => 'ingush',
        'io' => 'ido',
        'is' => 'islandsk',
        'it' => 'italiensk',
        'iu' => 'inuktitut',
        'ja' => 'japansk',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'machame',
        'jpr' => 'jødisk-persisk',
        'jrb' => 'jødisk-arabisk',
        'jv' => 'javanesisk',
        'ka' => 'georgisk',
        'kaa' => 'karakalpakisk',
        'kab' => 'kabylsk',
        'kac' => 'kachin',
        'kaj' => 'jju',
        'kam' => 'kamba',
        'kaw' => 'kawi',
        'kbd' => 'kabardian',
        'kbl' => 'kanembu',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'kapverdisk',
        'kfo' => 'koro',
        'kg' => 'kongo',
        'kgp' => 'kaingang',
        'kha' => 'khasi',
        'kho' => 'khotanesisk',
        'khq' => 'koyra-chiini',
        'ki' => 'kikuyu',
        'kj' => 'kuanyama',
        'kk' => 'kasakhisk',
        'kkj' => 'kako',
        'kl' => 'grønlandsk',
        'kln' => 'kalenjin',
        'km' => 'khmer',
        'kmb' => 'kimbundu',
        'kn' => 'kannada',
        'ko' => 'koreansk',
        'koi' => 'komi-permjakisk',
        'kok' => 'konkani',
        'kos' => 'kosraean',
        'kpe' => 'kpelle',
        'kr' => 'kanuri',
        'krc' => 'karatjai-balkar',
        'krl' => 'karelsk',
        'kru' => 'kurukh',
        'ks' => 'kashmiri',
        'ksb' => 'shambala',
        'ksf' => 'bafia',
        'ksh' => 'kölsch',
        'ku' => 'kurdisk',
        'kum' => 'kymyk',
        'kut' => 'kutenaj',
        'kv' => 'komi',
        'kw' => 'cornisk',
        'kwk' => 'kwakʼwala',
        'kxv' => 'kuvi',
        'ky' => 'kirgisisk',
        'la' => 'latin',
        'lad' => 'ladino',
        'lag' => 'langi',
        'lah' => 'lahnda',
        'lam' => 'lamba',
        'lb' => 'luxembourgsk',
        'lez' => 'lezghian',
        'lg' => 'ganda',
        'li' => 'limburgsk',
        'lij' => 'ligurisk',
        'lil' => 'lillooet',
        'lkt' => 'lakota',
        'lmo' => 'lombardisk',
        'ln' => 'lingala',
        'lo' => 'lao',
        'lol' => 'mongo',
        'lou' => 'Louisiana-kreolsk',
        'loz' => 'lozi',
        'lrc' => 'nordluri',
        'lsm' => 'saamia',
        'lt' => 'litauisk',
        'lu' => 'luba-Katanga',
        'lua' => 'luba-Lulua',
        'lui' => 'luiseno',
        'lun' => 'lunda',
        'lus' => 'lushai',
        'luy' => 'luyana',
        'lv' => 'lettisk',
        'mad' => 'madurese',
        'maf' => 'mafa',
        'mag' => 'magahi',
        'mai' => 'maithili',
        'mak' => 'makasar',
        'man' => 'mandingo',
        'mas' => 'masai',
        'mde' => 'maba',
        'mdf' => 'moksha',
        'mdr' => 'mandar',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'morisyen',
        'mg' => 'malagassisk',
        'mga' => 'middelirsk',
        'mgh' => 'makhuwa-meetto',
        'mgo' => 'meta',
        'mh' => 'marshallese',
        'mi' => 'maori',
        'mic' => 'micmac',
        'min' => 'minangkabau',
        'mk' => 'makedonsk',
        'ml' => 'malayalam',
        'mn' => 'mongolsk',
        'mnc' => 'manchu',
        'mni' => 'manipuri',
        'moe' => 'innu-aimun',
        'moh' => 'mohawk',
        'mos' => 'mossi',
        'mr' => 'marathi',
        'ms' => 'malajisk',
        'mt' => 'maltesisk',
        'mua' => 'mundang',
        'mus' => 'creek',
        'mwl' => 'mirandesisk',
        'mwr' => 'marwari',
        'my' => 'burmesisk',
        'mye' => 'myene',
        'myv' => 'erzya',
        'mzn' => 'mazenisk',
        'na' => 'nauru',
        'nan' => 'min-kinesisk',
        'nap' => 'napolitansk',
        'naq' => 'nama',
        'nb' => 'bokmål',
        'nd' => 'nordndebele',
        'nds' => 'nedertysk',
        'ne' => 'nepalesisk',
        'new' => 'newari',
        'ng' => 'ndonga',
        'nia' => 'nias',
        'niu' => 'niueansk',
        'nl' => 'nederlandsk',
        'nmg' => 'kwasio',
        'nn' => 'nynorsk',
        'nnh' => 'ngiemboon',
        'no' => 'norsk',
        'nog' => 'nogai',
        'non' => 'oldislandsk',
        'nqo' => 'n’ko',
        'nr' => 'sydndebele',
        'nso' => 'nordsotho',
        'nus' => 'nuer',
        'nv' => 'navajo',
        'nwc' => 'klassisk newarisk',
        'ny' => 'nyanja',
        'nym' => 'nyamwezi',
        'nyn' => 'nyankole',
        'nyo' => 'nyoro-sprog',
        'nzi' => 'nzima',
        'oc' => 'occitansk',
        'oj' => 'ojibwa',
        'ojb' => 'nordvestojibwa',
        'ojc' => 'centralojibwa',
        'ojs' => 'oji-cree',
        'ojw' => 'vestojibwa',
        'oka' => 'okanagan',
        'om' => 'oromo',
        'or' => 'oriya',
        'os' => 'ossetisk',
        'osa' => 'osage',
        'ota' => 'osmannisk tyrkisk',
        'pa' => 'punjabi',
        'pag' => 'pangasinan',
        'pal' => 'pahlavi',
        'pam' => 'pampanga',
        'pap' => 'papiamento',
        'pau' => 'palauansk',
        'pcm' => 'nigeriansk pidgin',
        'peo' => 'oldpersisk',
        'phn' => 'fønikisk',
        'pi' => 'pali',
        'pis' => 'pijin',
        'pl' => 'polsk',
        'pon' => 'ponape',
        'pqm' => 'maliseet-passamaquoddy',
        'prg' => 'preussisk',
        'pro' => 'oldprovencalsk',
        'ps' => 'pashto',
        'pt' => 'portugisisk',
        'qu' => 'quechua',
        'quc' => 'quiché',
        'raj' => 'rajasthani',
        'rap' => 'rapanui',
        'rar' => 'rarotonga',
        'rhg' => 'rohingya',
        'rm' => 'rætoromansk',
        'rn' => 'rundi',
        'ro' => 'rumænsk',
        'rof' => 'rombo',
        'rom' => 'romani',
        'ru' => 'russisk',
        'rup' => 'arumænsk',
        'rw' => 'kinyarwanda',
        'rwk' => 'rwa',
        'sa' => 'sanskrit',
        'sad' => 'sandawe',
        'sah' => 'jakutisk',
        'sam' => 'samaritansk aramæisk',
        'saq' => 'samburu',
        'sas' => 'sasak',
        'sat' => 'santali',
        'sba' => 'ngambay',
        'sbp' => 'sangu',
        'sc' => 'sardinsk',
        'scn' => 'siciliansk',
        'sco' => 'skotsk',
        'sd' => 'sindhi',
        'sdh' => 'sydkurdisk',
        'se' => 'nordsamisk',
        'see' => 'seneca',
        'seh' => 'sena',
        'sel' => 'selkupisk',
        'ses' => 'koyraboro senni',
        'sg' => 'sango',
        'sga' => 'oldirsk',
        'sh' => 'serbokroatisk',
        'shi' => 'tachelhit',
        'shn' => 'shan',
        'shu' => 'tchadisk arabisk',
        'si' => 'singalesisk',
        'sid' => 'sidamo',
        'sk' => 'slovakisk',
        'sl' => 'slovensk',
        'slh' => 'sydlushootseed',
        'sm' => 'samoansk',
        'sma' => 'sydsamisk',
        'smj' => 'lulesamisk',
        'smn' => 'enaresamisk',
        'sms' => 'skoltesamisk',
        'sn' => 'shona',
        'snk' => 'soninke',
        'so' => 'somali',
        'sog' => 'sogdiansk',
        'sq' => 'albansk',
        'sr' => 'serbisk',
        'srn' => 'sranan tongo',
        'srr' => 'serer',
        'ss' => 'swati',
        'ssy' => 'saho',
        'st' => 'sydsotho',
        'str' => 'straits salish',
        'su' => 'sundanesisk',
        'suk' => 'sukuma',
        'sus' => 'susu',
        'sux' => 'sumerisk',
        'sv' => 'svensk',
        'sw' => 'swahili',
        'swb' => 'comorisk',
        'syc' => 'klassisk syrisk',
        'syr' => 'syrisk',
        'szl' => 'schlesisk',
        'ta' => 'tamil',
        'tce' => 'sydtutchone',
        'te' => 'telugu',
        'tem' => 'temne',
        'teo' => 'teso',
        'ter' => 'tereno',
        'tet' => 'tetum',
        'tg' => 'tadsjikisk',
        'tgx' => 'tagish',
        'th' => 'thai',
        'tht' => 'tahltan',
        'ti' => 'tigrinya',
        'tig' => 'tigre',
        'tiv' => 'tivi',
        'tk' => 'turkmensk',
        'tkl' => 'tokelau',
        'tl' => 'tagalog',
        'tlh' => 'klingon',
        'tli' => 'tlingit',
        'tmh' => 'tamashek',
        'tn' => 'tswana',
        'to' => 'tongansk',
        'tog' => 'nyasa tongansk',
        'tok' => 'toki pona',
        'tpi' => 'tok pisin',
        'tr' => 'tyrkisk',
        'trv' => 'taroko',
        'ts' => 'tsonga',
        'tsi' => 'tsimshisk',
        'tt' => 'tatarisk',
        'ttm' => 'nordtutchone',
        'tum' => 'tumbuka',
        'tvl' => 'tuvaluansk',
        'tw' => 'twi',
        'twq' => 'tasawaq',
        'ty' => 'tahitiansk',
        'tyv' => 'tuvinian',
        'tzm' => 'centralmarokkansk tamazight',
        'udm' => 'udmurt',
        'ug' => 'uygurisk',
        'uga' => 'ugaristisk',
        'uk' => 'ukrainsk',
        'umb' => 'umbundu',
        'ur' => 'urdu',
        'uz' => 'usbekisk',
        've' => 'venda',
        'vec' => 'venetiansk',
        'vi' => 'vietnamesisk',
        'vmw' => 'makhuwa',
        'vo' => 'volapyk',
        'vot' => 'votisk',
        'vun' => 'vunjo',
        'wa' => 'vallonsk',
        'wae' => 'walsertysk',
        'wal' => 'walamo',
        'war' => 'waray',
        'was' => 'washo',
        'wbp' => 'walbiri',
        'wo' => 'wolof',
        'wuu' => 'wu-kinesisk',
        'xal' => 'kalmyk',
        'xh' => 'xhosa',
        'xnr' => 'kangri',
        'xog' => 'soga',
        'yao' => 'yao',
        'yap' => 'yapese',
        'yav' => 'yangben',
        'ybb' => 'yemba',
        'yi' => 'jiddisch',
        'yo' => 'yoruba',
        'yrl' => 'nheengatu',
        'yue' => 'kantonesisk',
        'za' => 'zhuang',
        'zap' => 'zapotec',
        'zbl' => 'blissymboler',
        'zen' => 'zenaga',
        'zgh' => 'tamazight',
        'zh' => 'kinesisk',
        'zu' => 'zulu',
        'zun' => 'zuni',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'moderne standardarabisk',
        'de_AT' => 'østrigsk tysk',
        'de_CH' => 'schweizerhøjtysk',
        'en_AU' => 'australsk engelsk',
        'en_CA' => 'canadisk engelsk',
        'en_GB' => 'britisk engelsk',
        'en_US' => 'amerikansk engelsk',
        'es_419' => 'latinamerikansk spansk',
        'es_ES' => 'europæisk spansk',
        'es_MX' => 'mexicansk spansk',
        'fa_AF' => 'dari',
        'fr_CA' => 'canadisk fransk',
        'fr_CH' => 'schweizisk fransk',
        'nl_BE' => 'flamsk',
        'pt_BR' => 'brasiliansk portugisisk',
        'pt_PT' => 'europæisk portugisisk',
        'ro_MD' => 'moldovisk',
        'sw_CD' => 'congolesisk swahili',
        'zh_Hans' => 'forenklet kinesisk',
        'zh_Hant' => 'traditionelt kinesisk',
    ],
];
